@@ -23,11 +23,13 @@ pub mod maxpro;
 pub mod motorbunny;
 pub mod mysteryvibe;
 pub mod nobra;
+pub mod patoo;
 pub mod picobong;
 pub mod prettylove;
 pub mod raw_protocol;
 pub mod realov;
 pub mod svakom;
+pub mod tcode_v03;
 pub mod thehandy;
 pub mod vibratissimo;
 pub mod vorze_sa;
@@ -85,11 +87,13 @@ pub fn get_default_protocol_map() -> DashMap<String, TryCreateProtocolFunc> {
   add_to_protocol_map::<motorbunny::Motorbunny>(&map, "motorbunny");
   add_to_protocol_map::<mysteryvibe::MysteryVibe>(&map, "mysteryvibe");
   add_to_protocol_map::<nobra::Nobra>(&map, "nobra");
+  add_to_protocol_map::<patoo::Patoo>(&map, "patoo");
   add_to_protocol_map::<picobong::Picobong>(&map, "picobong");
   add_to_protocol_map::<prettylove::PrettyLove>(&map, "prettylove");
   add_to_protocol_map::<raw_protocol::RawProtocol>(&map, "raw");
   add_to_protocol_map::<realov::Realov>(&map, "realov");
   add_to_protocol_map::<svakom::Svakom>(&map, "svakom");
+  add_to_protocol_map::<tcode_v03::TCodeV03>(&map, "tcode-v03");
   add_to_protocol_map::<thehandy::TheHandy>(&map, "thehandy");
   add_to_protocol_map::<vibratissimo::Vibratissimo>(&map, "vibratissimo");
   add_to_protocol_map::<vorze_sa::VorzeSA>(&map, "vorze-sa");
